<section id="buttons">
	<h1 class="heading">Buttons</h1>

	<h2>Default buttons</h2>
	<p>Button styles can be applied to anything with the <code>.btn</code> class applied. However, typically you'll want to apply these to only <code>&lt;a&gt;</code> and <code>&lt;button&gt;</code> elements for the best rendering.</p>
	
	<table class="table table-bordered table-striped">
		<thead>
			<tr>
				<th>Button</th>
				<th>class=""</th>
				<th>Description</th>
			</tr>
		</thead>
		<tbody>
			<tr>
				<td><button type="button" class="btn">Default</button></td>
				<td><code>btn</code></td>
				<td>Standard gray button with gradient</td>
			</tr>
			<tr>
				<td><button type="button" class="btn btn-primary">Primary</button></td>
				<td><code>btn btn-primary</code></td>
				<td>Provides extra visual weight and identifies the primary action in a set of buttons</td>
			</tr>
			<tr>
				<td><button type="button" class="btn btn-info">Info</button></td>
				<td><code>btn btn-info</code></td>
				<td>Used as an alternative to the default styles</td>
			</tr>
			<tr>
				<td><button type="button" class="btn btn-success">Success</button></td>
				<td><code>btn btn-success</code></td>
				<td>Indicates a successful or positive action</td>
			</tr>
			<tr>
				<td><button type="button" class="btn btn-warning">Warning</button></td>
				<td><code>btn btn-warning</code></td>
				<td>Indicates caution should be taken with this action</td>
			</tr>
			<tr>
				<td><button type="button" class="btn btn-danger">Danger</button></td>
				<td><code>btn btn-danger</code></td>
				<td>Indicates a dangerous or potentially negative action</td>
			</tr>
			<tr>
				<td><button type="button" class="btn btn-inverse">Inverse</button></td>
				<td><code>btn btn-inverse</code></td>
				<td>Alternate dark gray button, not tied to a semantic action or use</td>
			</tr>
			<tr>
				<td><button type="button" class="btn btn-link">Link</button></td>
				<td><code>btn btn-link</code></td>
				<td>Deemphasize a button by making it look like a link while maintaining button behavior</td>
			</tr>
		</tbody>
	</table>

	<h4>Cross browser compatibility</h4>
	<p>IE9 doesn't crop background gradients on rounded corners, so we remove it. Related, IE9 jankifies disabled <code>button</code> elements, rendering text gray with a nasty text-shadow that we cannot fix.</p>


	<h2>Button sizes</h2>
	<p>Fancy larger or smaller buttons? Add <code>.btn-large</code>, <code>.btn-small</code>, or <code>.btn-mini</code> for additional sizes.</p>
	<div class="bs-docs-example">
		<p>
			<button type="button" class="btn btn-large btn-primary">Large button</button>
			<button type="button" class="btn btn-large">Large button</button>
		</p>
		<p>
			<button type="button" class="btn btn-primary">Default button</button>
			<button type="button" class="btn">Default button</button>
		</p>
		<p>
			<button type="button" class="btn btn-small btn-primary">Small button</button>
			<button type="button" class="btn btn-small">Small button</button>
		</p>
		<p>
			<button type="button" class="btn btn-mini btn-primary">Mini button</button>
			<button type="button" class="btn btn-mini">Mini button</button>
		</p>
	</div>
<pre class="prettyprint linenums">
&lt;p&gt;
  &lt;button class="btn btn-large btn-primary" type="button"&gt;Large button&lt;/button&gt;
  &lt;button class="btn btn-large" type="button"&gt;Large button&lt;/button&gt;
&lt;/p&gt;
&lt;p&gt;
  &lt;button class="btn btn-primary" type="button"&gt;Default button&lt;/button&gt;
  &lt;button class="btn" type="button"&gt;Default button&lt;/button&gt;
&lt;/p&gt;
&lt;p&gt;
  &lt;button class="btn btn-small btn-primary" type="button"&gt;Small button&lt;/button&gt;
  &lt;button class="btn btn-small" type="button"&gt;Small button&lt;/button&gt;
&lt;/p&gt;
&lt;p&gt;
  &lt;button class="btn btn-mini btn-primary" type="button"&gt;Mini button&lt;/button&gt;
  &lt;button class="btn btn-mini" type="button"&gt;Mini button&lt;/button&gt;
&lt;/p&gt;
</pre>

	<p>Create block level buttons&mdash;those that span the full width of a parent&mdash; by adding <code>.btn-block</code>.</p>

	<div class="bs-docs-example">
		<div class="well" style="max-width: 400px; margin: 0 auto 10px;">
			<button type="button" class="btn btn-large btn-block btn-primary">Block level button</button>
			<button type="button" class="btn btn-large btn-block">Block level button</button>
		</div>
	</div>

<pre class="prettyprint linenums">
&lt;button class="btn btn-large btn-block btn-primary" type="button"&gt;Block level button&lt;/button&gt;
&lt;button class="btn btn-large btn-block" type="button"&gt;Block level button&lt;/button&gt;
</pre>

	<h2>One class, multiple tags</h2>
	
	<p>Use the <code>.btn</code> class on an <code>&lt;a&gt;</code>, <code>&lt;button&gt;</code>, or <code>&lt;input&gt;</code> element.</p>
	
	<form class="bs-docs-example">
		<a class="btn" href="">Link</a>
		<button class="btn" type="submit">Button</button>
		<input class="btn" type="button" value="Input">
		<input class="btn" type="submit" value="Submit">
	</form>

<pre class="prettyprint linenums">
&lt;a class="btn" href=""&gt;Link&lt;/a&gt;
&lt;button class="btn" type="submit"&gt;Button&lt;/button&gt;
&lt;input class="btn" type="button" value="Input"&gt;
&lt;input class="btn" type="submit" value="Submit"&gt;
</pre>
	<p>As a best practice, try to match the element for your context to ensure matching cross-browser rendering. If you have an <code>input</code>, use an <code>&lt;input type="submit"&gt;</code> for your button.</p>

	<br><br>

	<h1 class="heading">Button groups</h1>

	<p>Two basic options, along with two more specific variations.</p>

	<h3>Single button group</h3>
	
	<p>Wrap a series of buttons with <code>.btn</code> in <code>.btn-group</code>.</p>
	
	<div class="bs-docs-example">
		<div class="btn-group" style="margin: 9px 0 5px;">
			<button class="btn btn-primary">Left</button>
			<button class="btn btn-primary">Middle</button>
			<button class="btn btn-primary">Right</button>
		</div>
	</div>

<pre class="prettyprint linenums">
&lt;div class="btn-group"&gt;
  &lt;button class="btn"&gt;Left&lt;/button&gt;
  &lt;button class="btn"&gt;Middle&lt;/button&gt;
  &lt;button class="btn"&gt;Right&lt;/button&gt;
&lt;/div&gt;
</pre>

	<h3>Multiple button groups</h3>
	
	<p>Combine sets of <code>&lt;div class="btn-group"&gt;</code> into a <code>&lt;div class="btn-toolbar"&gt;</code> for more complex components.</p>
	
	<div class="bs-docs-example">
		<div class="btn-toolbar" style="margin: 0;">
			<div class="btn-group">
				<button class="btn">1</button>
				<button class="btn">2</button>
				<button class="btn">3</button>
				<button class="btn">4</button>
			</div>
			<div class="btn-group">
				<button class="btn">5</button>
				<button class="btn">6</button>
				<button class="btn">7</button>
			</div>
			<div class="btn-group">
				<button class="btn">8</button>
			</div>
		</div>
	</div>

<pre class="prettyprint linenums">
&lt;div class="btn-toolbar"&gt;
  &lt;div class="btn-group"&gt;
    ...
  &lt;/div&gt;
&lt;/div&gt;
</pre>

	

</section>

{ia_add_js}
	$(document).ready(function() {

		// make code pretty
		window.prettyPrint && prettyPrint();

	});
{/ia_add_js}

{ia_print_js files='_IA_URL_plugins/iabootstrap/js/front/google-code-prettify/prettify'}
{ia_print_css files='_IA_URL_plugins/iabootstrap/templates/front/css/iabootstrap, _IA_URL_plugins/iabootstrap/js/front/google-code-prettify/prettify'}